@@ -2,6 +2,10 @@ from django.db import models
 
 
 class CounterField(models.IntegerField):
+    """
+    CounterField wraps the standard django IntegerField. It exists primarily to allow for easy validation of
+    counter fields. The default value of a counter field is 0.
+    """
     def __init__(self, *args, **kwargs):
         kwargs['default'] = kwargs.get('default', 0)
         super(CounterField, self).__init__(*args, **kwargs)
@@ -11,4 +15,4 @@ try:
 except ImportError:
     pass
 else:
-    add_introspection_rules([], ["^pomoji\.django_counter_field\.fields\.CounterField"])
+    add_introspection_rules([], ["^django_counter_field\.fields\.CounterField"])
